import param

NAME = "pyct"

# version comes from git if available, otherwise from .version file
__version__ = str(param.version.Version(fpath=__file__, archive_commit="237a684",
                                        reponame=NAME))
